@@ -1,4 +1,5 @@
 """Declares :class:`StorageBackend` for use with Azure Blob Storage."""
+import re
 import os
 
 from azure.storage.blob import BlobServiceClient # pylint: disable=E0611
@@ -9,12 +10,18 @@ from .base import RemoteStorageBackendMixin
 
 class StorageBackend(RemoteStorageBackendMixin, BaseStorageBackend): # pylint: disable=R0801
     """A storage backend that uses Azure Blob Storage."""
+    kind = 'azure'
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.client = BlobServiceClient.from_connection_string(
             os.environ['AZURE_STORAGE_CONNECTION_STRING'])
         self.container_name = os.environ['AZURE_STORAGE_CONTAINER_NAME']
+        self.account_name = re.search('AccountName=([^;]+);',
+            os.environ['AZURE_STORAGE_CONNECTION_STRING']).group(1)
+        if ('AccountName=%s' % self.account_name)\
+        not in os.environ['AZURE_STORAGE_CONNECTION_STRING']: # pragma: no cover
+            raise ValueError("Unable to parse account name from connection string")
 
     def get_blob_client(self, path):
         """Returns an Azure blob client for the given path."""
@@ -46,6 +53,15 @@ class StorageBackend(RemoteStorageBackendMixin, BaseStorageBackend): # pylint: d
         """
         return self.get_blob_client(path).exists()
 
+    def update_labels(self, labels):
+        """Update dictionary `labels` with the label for a specific
+        storage backend.
+        """
+        labels.update({
+            'azure.microsoft.com/blob-storage-account': self.account_name,
+            'azure.microsoft.com/blob-storage-container': self.container_name
+        })
+
     def read(self, handler, size=-1):
         """Read at most n characters from handler.
 
