@@ -7,6 +7,7 @@ from .base import BaseStorageBackend
 
 class LocalDiskBackend(BaseStorageBackend):
     """A storage backend that uses the local filesystem."""
+    kind = 'local'
 
     def close(self, handler):
         """Flush and close the IO object.
@@ -33,6 +34,11 @@ class LocalDiskBackend(BaseStorageBackend):
             os.makedirs(os.path.dirname(local_path))
         return open(local_path, handler.mode)
 
+    def update_labels(self, labels): # pylint: disable=W0107
+        """Update dictionary `labels` with the label for a specific
+        storage backend.
+        """
+
     def read(self, handler, size=-1):
         """Read at most n characters from handler.
 
