@@ -11,6 +11,7 @@ from ..local import LocalDiskBackend
 
 class LocalDiskBackendTestCase(unittest.TestCase):
     backend_class = LocalDiskBackend
+    capabilities = ['unlink']
 
     def setUp(self):
         self.backend = self.get_backend()
@@ -124,3 +125,25 @@ class LocalDiskBackendTestCase(unittest.TestCase):
 
         with self.backend.open(src, 'rt') as fd:
             self.assertIsInstance(fd.read(), str)
+
+    def test_unlink_file(self):
+        if 'unlink' not in self.capabilities:
+            raise unittest.SkipTest("unlink not supported for backend.")
+        src = 'foo'
+        with self.backend.open(src, 'w') as f:
+            f.write("Hello world!")
+
+        self.assertTrue(self.backend.exists(src))
+        self.backend.unlink(src)
+        self.assertTrue(not self.backend.exists(src))
+
+    def test_unlink_dir(self):
+        if 'unlink' not in self.capabilities:
+            raise unittest.SkipTest("unlink not supported for backend.")
+        src = 'foo/bar/baz/taz'
+        with self.backend.open(src, 'w') as f:
+            f.write("Hello world!")
+
+        self.assertTrue(self.backend.exists(src))
+        self.backend.unlink('foo/bar/baz')
+        self.assertTrue(not self.backend.exists(src))
